@@ -108,6 +108,7 @@
 ( "ejs"                     , "file_type_ejs"                     ),
 ( "el"                      , "file_type_emacs"                   ),
 ( "elc"                     , "file_type_emacs"                   ),
+( "elm"                     , "file_type_elm"                     ),
 ( "ember-cli"               , "file_type_ember"                   ),
 ( "enc"                     , "file_type_license"                 ),
 ( "ensime"                  , "file_type_ensime"                  ),
@@ -136,6 +137,7 @@
 ( "flv"                     , "file_type_video"                   ),
 ( "fods"                    , "file_type_excel2"                  ),
 ( "fossaignore"             , "file_type_fossa"                   ),
+( "fs"                      , "file_type_fsharp"                  ),
 ( "fsproj"                  , "file_type_fsproj"                  ),
 ( "gemfile"                 , "file_type_bundler"                 ),
 ( "gif"                     , "file_type_image"                   ),
@@ -156,6 +158,7 @@
 ( "hgignore"                , "file_type_mercurial"               ),
 ( "hl"                      , "file_type_binary"                  ),
 ( "hpp"                     , "file_type_cppheader"               ),
+( "hs"                      , "file_type_haskell"                 ),
 ( "html"                    , "file_type_html"                    ),
 ( "htmlhintrc"              , "file_type_htmlhint"                ),
 ( "huskyrc"                 , "file_type_husky"                   ),
@@ -176,6 +179,7 @@
 ( "iuml"                    , "file_type_plantuml"                ),
 ( "ivs"                     , "file_type_audio"                   ),
 ( "jade-lintrc"             , "file_type_pug"                     ),
+( "jar"                     , "file_type_jar"                     ),
 ( "java"                    , "file_type_java"                    ),
 ( "jestrc"                  , "file_type_jest"                    ),
 ( "jpeg"                    , "file_type_image"                   ),
@@ -192,6 +196,7 @@
 ( "jsonld"                  , "file_type_jsonld"                  ),
 ( "jsp"                     , "file_type_jsp"                     ),
 ( "jss"                     , "file_type_jss"                     ),
+( "kdl"                     , "file_type_config"                  ),
 ( "key"                     , "file_type_key"                     ),
 ( "kit"                     , "file_type_codekit"                 ),
 ( "kiteignore"              , "file_type_kite"                    ),
@@ -351,6 +356,7 @@
 ( "pptx"                    , "file_type_powerpoint2"             ),
 ( "prettierignore"          , "file_type_prettier"                ),
 ( "prettierrc"              , "file_type_prettier"                ),
+( "prisma"                  , "file_type_prisma"                  ),
 ( "pro"                     , "file_type_prolog"                  ),
 ( "procfile"                , "file_type_procfile"                ),
 ( "psd"                     , "file_type_photoshop2"              ),
@@ -381,6 +387,7 @@
 ( "rar"                     , "file_type_zip2"                    ),
 ( "raw"                     , "file_type_audio"                   ),
 ( "rb"                      , "file_type_ruby"                    ),
+( "re"                      , "file_type_reason"                  ),
 ( "reg"                     , "file_type_registry"                ),
 ( "rego"                    , "file_type_rego"                    ),
 ( "rehypeignore"            , "file_type_rehype"                  ),
@@ -400,6 +407,8 @@
 ( "rwd"                     , "file_type_matlab"                  ),
 ( "sailsrc"                 , "file_type_sails"                   ),
 ( "sass"                    , "file_type_sass"                    ),
+( "sbt"                     , "file_type_sbt"                     ),
+( "scala"                   , "file_type_scala"                   ),
 ( "scpt"                    , "file_type_binary"                  ),
 ( "scptd"                   , "file_type_binary"                  ),
 ( "scssm"                   , "file_type_scss"                    ),
@@ -440,6 +449,7 @@
 ( "tar"                     , "file_type_zip2"                    ),
 ( "tcl"                     , "file_type_tcl"                     ),
 ( "texi"                    , "file_type_tex"                     ),
+( "tf"                      , "file_type_terraform"               ),
 ( "tfignore"                , "file_type_tfs"                     ),
 ( "tfstate"                 , "file_type_terraform"               ),
 ( "tgz"                     , "file_type_zip2"                    ),
